@@ -15,6 +15,7 @@
 package Google::Ads::Common::OAuth2ApplicationsHandler;
 
 use strict;
+use warnings;
 use version;
 use base qw(Google::Ads::Common::OAuth2BaseHandler
   Google::Ads::Common::OAuthApplicationsHandlerInterface);
@@ -252,6 +253,8 @@ A hash reference with the following keys:
   oAuth2RedirectUri => "secret",
 }
 
+=back
+
 =head2 is_auth_enabled
 
 Refer to L<Google::Ads::Common::AuthHandlerInterface> documentation of this
